# Modeling 

PyARPES is not and does aim to be a theory code. 
There are many good resources already in the scientific 
Python community, some of which we have included 
[for reference elsewhere](/cmp-stack).

TODO  


